package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWldv;
import com.ruoyi.tcZz.domain.TcYqzs;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcWljgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网络监测Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "网络监测")
@RequestMapping("/tcZz/networkSecurity/cybersecurity")
public class TcWljgController extends BaseController
{
    @Autowired
    private ITcWljgService tcWljgService;


    /**
     * 导出网络监测列表
     */
    @ApiOperation("导出网络监测列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWljg tcWljg)
    {
        List<TcWljg> list = tcWljgService.selectTcWljgList(tcWljg);
        ExcelUtil<TcWljg> util = new ExcelUtil<TcWljg>(TcWljg.class);
        util.exportExcel(response, list, "网络监测数据");
    }

    /**
     * 获取网络监测详细信息
     */
    @ApiOperation("获取网络监测详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWljgService.selectTcWljgById(id));
    }

    /**
     * 新增网络监测
     */
    @ApiOperation("新增网络监测")
    @PostMapping
    public AjaxResult add(@RequestBody TcWljg tcWljg)
    {
        return toAjax(tcWljgService.insertTcWljg(tcWljg));
    }

    /**
     * 修改网络监测
     */
    @ApiOperation("修改网络监测")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWljg tcWljg)
    {
        return toAjax(tcWljgService.updateTcWljg(tcWljg));
    }

    /**
     * 删除网络监测
     */
    @ApiOperation("删除网络监测")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWljgService.deleteTcWljgByIds(ids));
    }


    /**
     * 查询网络监测列表
     */
    @ApiOperation(value = "查询网络监测列表",response = TcWljg.class)
    @GetMapping("/ListNoToken")
    public TableDataInfo ListNoToken(TcWljg tcWljg)
    {
        startPage();
        List<TcWljg> list = tcWljgService.selectTcWljgList(tcWljg);
        return getDataTable(list);
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWljg> util = new ExcelUtil<TcWljg>(TcWljg.class);
        List<TcWljg> tcWljgList = util.importExcel(file.getInputStream());
        tcWljgService.importUser(tcWljgList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWljgService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWljg> util = new ExcelUtil<TcWljg>(TcWljg.class);
        util.importTemplateExcel(response, " 网络监测列表");
    }
}
